masked method

DataFrame masked(
  1. List<bool> mask, {
  2. bool asView = true,
})

Returns a masked DataFrame.

asView set to true leads to a view of the current data being returned, otherwise a copy will be returned.

Implementation

DataFrame masked(List<bool> mask, {bool asView = true}) =>
    _viewOrCopy(_trackedColumnNames.l, applyMask(mask).toList(), asView);